#
# spec file for package libosmo-sccp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libosmo-sccp
Version:        0.8.1
Release:        lp150.1.3
%define libversion 0_8_1
Summary:        Osmocom library for the A-bis interface between BTS and BSC
License:        AGPL-3.0+ and GPL-2.0+
Group:          Hardware/Mobile
Url:            http://openbsc.osmocom.org/

#Git-Clone:	git://git.osmocom.org/libosmo-sccp
Source:         %name-%version.tar.xz
Patch1:         0001-build-fixes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake >= 1.6
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkg-config >= 0.20
BuildRequires:  xz
BuildRequires:  pkgconfig(libosmo-netif) >= 0.1.0
BuildRequires:  pkgconfig(libosmocore) >= 0.10.0
BuildRequires:  pkgconfig(libosmogsm) >= 0.10.0
BuildRequires:  pkgconfig(libosmovty) >= 0.10.0

%description
SCCP is a network layer protocol that provides extended routing, flow
control, segmentation, connection-orientation, and error correction
facilities in Signaling System 7 telecommunications networks. SCCP is
heavily used in cellular networks such as GSM.

%package -n libosmo-mtp-%libversion
Summary:        Osmocom Message Transfer Part library
License:        GPL-2.0+
Group:          System/Libraries

%description -n libosmo-mtp-%libversion
The Message Transfer Part (MTP) is part of the Signaling System 7
(SS7) used for communication in Public Switched Telephone Networks.
MTP is responsible for reliable, unduplicated and in-sequence
transport of SS7 messages between communication partners.

%package -n libosmo-mtp-devel
Summary:        Development files for the Osmocom MTP library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libosmo-mtp-%libversion = %version

%description -n libosmo-mtp-devel
MTP is part of SS7 used for communication in Public Switched
Telephone Networks.

This subpackage contains the development files for the Osmocom MTP
library.

%package -n libosmo-sccp-%libversion
Summary:        Osmocom Signalling Connection Control Part library
License:        GPL-2.0+
Group:          System/Libraries

%description -n libosmo-sccp-%libversion
The Signalling Connection Control Part (SCCP) is a network layer
protocol that provides extended routing, flow control, segmentation,
connection-orientation, and error correction facilities in Signaling
System 7 telecommunications networks. SCCP relies on the services of
MTP for basic routing and error detection.

%package -n libosmo-sccp-devel
Summary:        Development files for the Osmocom SCCP library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libosmo-sccp-%libversion = %version

%description -n libosmo-sccp-devel
SCCP is a network layer protocol that provides routing, flow control,
segmentation, connection-orientation, and error correction facilities
in SS7 telecommunications networks.

This subpackage contains the development files for the Osmocom SCCP
library.

%package -n libosmo-sigtran0
Summary:        Osmocom SIGTRAN library
License:        GPL-2.0+
Group:          System/Libraries

%description -n libosmo-sigtran0
Osmocom implementation of (parts of) SIGTRAN.

%package -n libosmo-sigtran-devel
Summary:        Development files for the Osmocom sigtran library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libosmo-sigtran0 = %version

%description -n libosmo-sigtran-devel
Osmocom implementation of (parts of) SIGTRAN.

This subpackage contains the development files for the Osmocom
SIGTRAN library.

%package -n libosmo-xua-%libversion
Summary:        Osmocom Message Transfer Part 2 User Adaptation library
License:        GPL-2.0+
Group:          System/Libraries

%description -n libosmo-xua-%libversion
M2UA (RFC 3331) provides an SCTP (RFC 3873) adaptation layer for the
seamless backhaul of MTP Level 2 user messages and service interface
across an IP network.

%package -n libosmo-xua-devel
Summary:        Development files for the Osmocom M2UA library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libosmo-sigtran-devel = %version
Requires:       libosmo-xua-%libversion = %version

%description -n libosmo-xua-devel
M2UA provides an SCTP adaptation layer for MTP level 2 user messages
and service interface across an IP network.

This subpackage contains the development files for the Osmocom M2UA
library.

%prep
%setup -q
%patch -P 1 -p1

%build
echo "%version" >.tarball-version
autoreconf -fiv
%configure --enable-shared --disable-static --includedir="%_includedir/%name"
make %{?_smp_mflags}

%install
%make_install
find "%buildroot/%_libdir" -type f -name "*.la" -delete

%check
%ifnarch ppc64 sparc64 s390x
# still BE problems?
make %{?_smp_mflags} check
%endif

%post   -n libosmo-mtp-%libversion -p /sbin/ldconfig
%postun -n libosmo-mtp-%libversion -p /sbin/ldconfig
%post   -n libosmo-sccp-%libversion -p /sbin/ldconfig
%postun -n libosmo-sccp-%libversion -p /sbin/ldconfig
%post   -n libosmo-sigtran0 -p /sbin/ldconfig
%postun -n libosmo-sigtran0 -p /sbin/ldconfig
%post   -n libosmo-xua-%libversion -p /sbin/ldconfig
%postun -n libosmo-xua-%libversion -p /sbin/ldconfig

%files -n libosmo-mtp-%libversion
%defattr(-,root,root)
%_libdir/libosmo-mtp-%version.so

%files -n libosmo-mtp-devel
%defattr(-,root,root)
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/mtp/
%_libdir/libosmo-mtp.so
%_libdir/pkgconfig/libosmo-mtp.pc

%files -n libosmo-sccp-%libversion
%defattr(-,root,root)
%_libdir/libosmo-sccp.so
%_libdir/libosmo-sccp-%version.so

%files -n libosmo-sccp-devel
%defattr(-,root,root)
%_bindir/osmo-stp
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/sccp/
%_libdir/pkgconfig/libosmo-sccp.pc

%files -n libosmo-sigtran0
%defattr(-,root,root)
%_libdir/libosmo-sigtran.so.0*

%files -n libosmo-sigtran-devel
%defattr(-,root,root)
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/sigtran/
%_libdir/libosmo-sigtran.so
%_libdir/pkgconfig/libosmo-sigtran.pc

%files -n libosmo-xua-%libversion
%defattr(-,root,root)
%_libdir/libosmo-xua-%version.so

%files -n libosmo-xua-devel
%defattr(-,root,root)
%_libdir/libosmo-xua.so
%_libdir/pkgconfig/libosmo-xua.pc

%changelog
* Thu Dec 28 2017 jengelh@inai.de
- Update to new upstream release 0.8.1
  * sccp_scrc: fix Network Indicator in SIO composition
  * osmo_sccp_addr_encode(): Fix truncation of point codes
* Thu Oct 26 2017 dimstar@opensuse.org
- Fix names of shared library packages: the version is 0.7.0.284
  and the soname contains the entire version. As this results in
  package rename, we exceptionally obsolete the old/wrong package
  name in order to facilitate error-free upgrades.
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.284
  * vty: add 'asp' / 'local-ip' command
  * osmo_ss7_vty: fix 'as' / 'routing-key' command
  * OsmoSTP: Install our default set of signal handlers
  * Fix SCCP client crash on xUA server (STP) disconnect
  * vty: hide SG commands when running as ASP
  * sccp: fix creating of the default route in simple client
  * sccp: derive local address from given sccp instance
* Fri Apr 28 2017 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.208
  * Add new 'osmo_ss7' SS7 core code with M3UA, ASP/AS FSM, ...
  * Add SCCP <-> SUA message transcoding routines
  * Add tests for xUA code + SCCP/SUA transcoding
  * Add new SCCP implementation
  * Add M3UA RKM (routing key management) support, SGW side only
  * SCCP: Add VTY interface for SCCP
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.11
  * Add missing OSMO_SCCP_SSN_RANAP for RANAP SSN
  * Properly define SCCP_SAP_USER without random magic number
  * Import SUA (SCCP User Adaptation) and SCCP User SAP
* Thu Sep 10 2015 jengelh@inai.de
- Update to new upstream release 0.7.0
  * sccp: Allow to specify the context of the incoming message
  * mtp: Correct the pointcode mask
  * mtp: Add implementation from cellmgr
  * m3ua: Add the definition of the protocol data header
  * xua: Generalize the m2ua_msg and call it xua_msg
  * XUA: Move m2ua headers to sigtran, create xua_types.h
  and m3ua_types.h
  * sccp: Create sccp_create_cr and use it in the connection creation
* Mon Jul 21 2014 jengelh@inai.de
- Initial package (version 0.0.6.3) for build.opensuse.org
